function init(hero) {
    hero.setName("Deadzone");
    hero.setTier(7);

    hero.setHelmet("item.superhero_armor.piece.cowl");
    hero.setChestplate("item.superhero_armor.piece.chestpiece");
    hero.setLeggings("item.superhero_armor.piece.pants");
    hero.setBoots("item.superhero_armor.piece.boots");

    hero.addPowers("smp:power_negation");
    hero.addAttribute("PUNCH_DAMAGE", 6.5, 0);
    hero.addAttribute("WEAPON_DAMAGE", 3.5, 0);
    hero.addAttribute("JUMP_HEIGHT", 1.0, 0);
    hero.addAttribute("FALL_RESISTANCE", 6.0, 0);
    hero.addAttribute("SPRINT_SPEED", 0.6, 1);
    hero.addAttribute("IMPACT_DAMAGE", 0.5, 1);

    hero.addKeyBind("SHADOWFORM", "key.shadowForm", 2);
    hero.addKeyBind("SHIELD", "key.forcefield", 3);
    hero.addKeyBind("BLADE", "Toggle Dagger", 4);
    hero.addKeyBind("CHARGED_JUMP", "Charged Jump", 5);

    hero.setModifierEnabled(isModifierEnabled);
    hero.setKeyBindEnabled(isKeyBindEnabled);

    hero.setHasProperty((entity, property) => property == "MASK_TOGGLE");

    hero.addAttributeProfile("SHIELD", shieldProfile);
    hero.addAttributeProfile("JUMP_1", firstJumpProfile);
    hero.addAttributeProfile("JUMP_2", secondJumpProfile);
    hero.addAttributeProfile("JUMP_3", thirdJumpProfile);
    hero.setAttributeProfile(getProfile);

    hero.setDamageProfile(entity => entity.getData("fiskheroes:blade") ? "DAGGER" : null);
    hero.addDamageProfile("DAGGER", {
        "types": {
            "SHARP": 1.0,
            "FIRE": 0.8
        },
        "properties": {
            "EFFECTS": [
                {
                  "id": "fiskheroes:disable_phasing",
                  "duration": 2400,
                  "amplifier": 0,
                  "chance": 1
                },
                {
                  "id": "fiskheroes:disable_speed",
                  "duration": 2400,
                  "amplifier": 0,
                  "chance": 1
                },
                {
                  "id": "fiskheroes:tutridium",
                  "duration": 2400,
                  "amplifier": 0,
                  "chance": 1
                }
              ]
        }
      });

    hero.addSoundEvent("MASK_OPEN", "fiskheroes:reverse_flash_vibration_loop");

    hero.setTickHandler((entity, manager) => {
        manager.incrementData(entity, "smp:dyn/sprint_timer", 7, entity.isSprinting() && entity.isOnGround() && entity.getData("fiskheroes:blade") && !entity.getData("fiskheroes:shield"));
        manager.incrementData(entity, "smp:dyn/dagger_timer", 4, entity.isSprinting() && entity.getData("fiskheroes:blade") && !entity.getData("fiskheroes:shield") && !entity.getData("fiskheroes:gliding") && !entity.getData("fiskheroes:beam_charging"));

        manager.setData(entity, "fiskheroes:energy_projection", entity.getData("fiskheroes:mask_open"));
    });
}

function isModifierEnabled(entity, modifier) {
    if (modifier.name() == "fiskheroes:gliding") {
        return entity.getData("fiskheroes:blade");
    }
    else if (modifier.name() == "fiskheroes:shadowform" || modifier.name() == "fiskheroes:flight") {
        if (modifier.name() == "fiskheroes:flight") {
            return entity.getData("fiskheroes:blade") && entity.getData("fiskheroes:shadowform");
        }
        return entity.getData("fiskheroes:blade");
    }
    return true;
}

function isKeyBindEnabled(entity, keyBind) {
    if (keyBind == "CHARGED_JUMP") {
        return entity.isOnGround() && !entity.getData("fiskheroes:shield");
    }
    else if (keyBind == "SHADOWFORM") {
        return entity.getData("fiskheroes:blade");
    }
    return true;
}

function getProfile(entity) {
    var j = entity.getData("smp:dyn/jump_timer")
    return entity.getData("fiskheroes:shield") ? "SHIELD" : j == 1 ? "JUMP_3" : j >= 1 / 1.5 ? "JUMP_2" : j >= 1 / 3 ? "JUMP_1" : null;
}

function firstJumpProfile(profile) {
    profile.inheritDefaults();
    profile.addAttribute("JUMP_HEIGHT", 5.3, 0);
}

function secondJumpProfile(profile) {
    profile.inheritDefaults();
    profile.addAttribute("JUMP_HEIGHT", 10.7, 0);
}

function thirdJumpProfile(profile) {
    profile.inheritDefaults();
    profile.addAttribute("JUMP_HEIGHT", 16.0, 0);
}

function shieldProfile(profile) {
    profile.inheritDefaults();
    profile.addAttribute("BASE_SPEED", -0.75, 1);
    profile.addAttribute("JUMP_HEIGHT", -2.0, 1);
}