function init(hero) {
    hero.setName("Thundercrash");
    hero.setTier(8);

    hero.setChestplate("item.superhero_armor.piece.torso");

    hero.addPowers("smp:dark_gamma_radiation");
    hero.addAttribute("PUNCH_DAMAGE", 10.5, 0);
    hero.addAttribute("SPRINT_SPEED", 0.8, 1);
    hero.addAttribute("JUMP_HEIGHT", 2.5, 0);
    hero.addAttribute("FALL_RESISTANCE", 1.0, 1);
    hero.addAttribute("STEP_HEIGHT", 0.5, 0);

    hero.addKeyBind("CHARGED_BEAM", "Thunderclap", 1);
    hero.addKeyBind("GROUND_SMASH", "key.groundSmash", 2);
    hero.addKeyBind("GAMMA", "Gamma Transformation", 5);

    hero.setModifierEnabled(isModifierEnabled);
    hero.setKeyBindEnabled(isKeyBindEnabled);
    hero.setTierOverride(entity => entity.getData("smp:dyn/gamma") ? 8 : 0);

    hero.setAttributeProfile(entity => entity.getData("smp:dyn/gamma") ? null : "INACTIVE");
    hero.addAttributeProfile("INACTIVE", profile => {
        profile.revokeAugments();
    });

    hero.setDefaultScale((entity) => entity.is("DISPLAY") ? 1.5 : 1);

    hero.setDamageProfile(entity => entity.getData("smp:dyn/gamma") && !entity.getHeldItem().isWeapon() ? "PUNCH" : null);
    hero.addDamageProfile("PUNCH", {
        "types": {
            "BLUNT": 1.0,
            "ELECTRICITY": 0.2
        }
    });

    hero.setTickHandler((entity, manager) => {
        manager.setData(entity, "fiskheroes:size_state", (entity.getData("smp:dyn/gamma") || entity.is("DISPLAY")) ? 1 : -1)

        manager.incrementData(entity, "smp:dyn/jump_timer", 100, 1, entity.getData("smp:dyn/gamma") && entity.isSprinting())

        groundSlam(entity, manager, "smp:suit.thundercrash.thunderclap", 1, 1.15 - Math.random() * 0.3);
    });
}

function groundSlam(entity, manager, sound, volume, pitch) {
    var t = entity.getData("smp:dyn/superhero_landing_ticks");
    var timer = entity.getData("smp:dyn/gamma_timer") == 1;

    if  (timer && entity.isSprinting() && entity.getData("smp:dyn/leap_cooldown") == 1 && entity.motionY() > 0.3 && !entity.isOnGround() && entity.getData("smp:dyn/leap_timer") == 0) {
        manager.setDataWithNotify(entity, "smp:dyn/leap", true);
    }
    else if  (entity.isOnGround() || entity.isInWater() || !timer || entity.isSneaking()) {
        manager.setDataWithNotify(entity, "smp:dyn/leap", false);
    }

    manager.incrementData(entity, "smp:dyn/leap_cooldown", 20, 8, timer && t == 0 && entity.isOnGround() && !entity.isInWater() && entity.isSneaking(), !entity.isSneaking() && entity.getData("smp:dyn/leap_cooldown") < 1);
    manager.incrementData(entity, "smp:dyn/leap_timer", 12, entity.getData("smp:dyn/leap"));
    

    if (timer && t == 0 && entity.motionY() < -1.0 && entity.world().blockAt(entity.pos().add(0, -2, 0)).isSolid() && entity.getData("smp:dyn/leap") > 0 && !entity.isInWater()) {
        manager.setDataWithNotify(entity, "smp:dyn/superhero_landing_ticks", t = 12);
        manager.setInterpolatedData(entity, "smp:dyn/leap_cooldown", 0);
        entity.playSound(sound, volume, pitch);
    }
    else if (!timer) {
        manager.setInterpolatedData(entity, "smp:dyn/leap_cooldown", 0);
    }
    else if (t > 0) {
        manager.setData(entity, "smp:dyn/superhero_landing_ticks", --t);
    }

    manager.incrementData(entity, "smp:dyn/superhero_landing_timer", 2, 8, t > 0);
    manager.setDataWithNotify(entity, "fiskheroes:heat_vision", entity.getData("smp:dyn/superhero_landing_timer") >= 0.9)
}

function isModifierEnabled(entity, modifier) {
    if (modifier.name() != "fiskheroes:transformation" && !entity.getData("smp:dyn/gamma")) {
        return false;
    }
    else if (modifier.name() == "fiskheroes:leaping") {
        var leap = Math.floor(entity.getData("smp:dyn/jump_timer") * 4 + 1)
        return modifier.id() == (entity.getData("smp:dyn/leap_cooldown") ? "LEAP_4" : "LEAP_" + leap);
    }

    return true;
}

function isKeyBindEnabled(entity, keyBind) {
    if (keyBind != "GAMMA") {
        return entity.getData("smp:dyn/gamma");
    }

    return true;
}
