function init(hero) {
    hero.setName("Wavebreaker");
    hero.setTier(5);
    
    hero.setHelmet("Earrings");
    hero.setChestplate("Pectoral");
    hero.setLeggings("Trunks");
    hero.setBoots("Ankle Bracelets");
    
    hero.addPowers("smp:trident", "smp:hydrokinesis");
    hero.addAttribute("PUNCH_DAMAGE", 10.5, 0);
    hero.addAttribute("WEAPON_DAMAGE", 3.5, 0);
    hero.addAttribute("JUMP_HEIGHT", 1.5, 0);
    hero.addAttribute("FALL_RESISTANCE", 8.0, 0);
    hero.addAttribute("SPRINT_SPEED", 0.3, 1);

    hero.addKeyBind("BLADE", "Toggle Trident", 5);

    hero.addAttributeProfile("DROUGHT9", droughtNineProfile);
    hero.addAttributeProfile("DROUGHT8", droughtEightProfile);
    hero.addAttributeProfile("DROUGHT7", droughtSevenProfile);
    hero.addAttributeProfile("DROUGHT6", droughtSixProfile);
    hero.addAttributeProfile("DROUGHT5", droughtFiveProfile);
    hero.addAttributeProfile("DROUGHT4", droughtFourProfile);
    hero.addAttributeProfile("DROUGHT3", droughtThreeProfile);
    hero.addAttributeProfile("DROUGHT2", droughtTwoProfile);
    hero.addAttributeProfile("DROUGHT1", droughtOneProfile);
    hero.addAttributeProfile("DROUGHT0", droughtZeroProfile);
    hero.setAttributeProfile(getProfile);
    hero.setDamageProfile(getProfile);
    hero.setTierOverride(getTierOverride);
    hero.setModifierEnabled(isModifierEnabled);

    hero.setTickHandler((entity, manager) => {
        manager.setData(entity, "fiskheroes:shield", entity.getData("fiskheroes:blade"));

        manager.setData(entity, "smp:dyn/dry", !entity.isWet());

        if (entity.hasPotionEffect(2) && entity.hasPotionEffect(9) && entity.hasPotionEffect(18)) {
            manager.setData(entity, "smp:dyn/drought_timer", entity.getData("smp:dyn/drought_timer") + 0.0015);
        }
        
        manager.incrementData(entity, "smp:dyn/in_water", 6, 12, entity.isInWater());

        if (!entity.isSneaking() && entity.isInWater()) {
            manager.setData(entity, "fiskheroes:flying", true);
        }
    });
}

function isModifierEnabled(entity, modifier) {
    var drought = 10 * (1 - (entity.getInterpolatedData("smp:dyn/drought_timer")))
    switch (modifier.id()) {
        case "a10":
        case "b10":
            return (drought >= 9 && drought <= 10);
        case "a9":
        case "b9":
            return (drought >= 8 && drought < 9);
        case "a8":
        case "b8":
            return (drought >= 7 && drought < 8);
        case "a7":
        case "b7":
            return (drought >= 6 && drought < 7);
        case "a6":
        case "b6":
            return (drought >= 5 && drought < 6);
        case "a5":
        case "b5":
            return (drought >= 4 && drought < 5);
        case "a4":
        case "b4":
            return (drought >= 3 && drought < 4);
        case "a3":
        case "b3":
            return (drought >= 2 && drought < 3);
        case "a2":
        case "b2":
            return (drought >= 1 && drought < 2);
        case "a1":
        case "b1":
            return (drought > 0 && drought < 1);
    }
    switch (modifier.name()) {
        case "fiskheroes:fire_weakness":
            return !entity.isWet();
        default:
            return true;
    }
}

function getTierOverride(entity) {
    return 1//Math.ceil(5 * (1 - (entity.getInterpolatedData("smp:dyn/drought_timer"))));
}

function getProfile(entity) {
    var drought = 10 * (1 - (entity.getInterpolatedData("smp:dyn/drought_timer")))
    if (drought >= 8.0 && drought < 9.0)
    return "DROUGHT9";
    if (drought >= 7.0 && drought < 8.0)
    return "DROUGHT8";
    if (drought >= 6.0 && drought < 7.0)
    return "DROUGHT7";
    if (drought >= 5.0 && drought < 6.0)
    return "DROUGHT6";
    if (drought >= 4.0 && drought < 5.0)
    return "DROUGHT5";
    if (drought >= 3.0 && drought < 4.0)
    return "DROUGHT4";
    if (drought >= 2.0 && drought < 3.0)
    return "DROUGHT3";
    if (drought >= 1.0 && drought < 2.0)
    return "DROUGHT2";
    if (drought > 0.0 && drought < 1.0)
    return "DROUGHT1";
    if (drought == 0)
    return "DROUGHT0";
}

function droughtNineProfile(profile) {
    profile.addAttribute("PUNCH_DAMAGE", 8.75, 0);
    profile.addAttribute("WEAPON_DAMAGE", 2.9, 0);
    profile.addAttribute("JUMP_HEIGHT", 1.325, 0);
    profile.addAttribute("FALL_RESISTANCE", 7.075, 0);
    profile.addAttribute("SPRINT_SPEED", 0.27, 1);
    profile.addAttribute("BASE_SPEED", -0.07, 1);
}

function droughtEightProfile(profile) {
    profile.addAttribute("PUNCH_DAMAGE", 9.7, 0);
    profile.addAttribute("WEAPON_DAMAGE", 2.3, 0);
    profile.addAttribute("JUMP_HEIGHT", 1.15, 0);
    profile.addAttribute("FALL_RESISTANCE", 6.15, 0);
    profile.addAttribute("SPRINT_SPEED", 0.24, 1);
    profile.addAttribute("BASE_SPEED", -0.14, 1);
}

function droughtSevenProfile(profile) {
    profile.addAttribute("PUNCH_DAMAGE", 8.1, 0);
    profile.addAttribute("WEAPON_DAMAGE", 1.7, 0);
    profile.addAttribute("JUMP_HEIGHT", 0.975, 0);
    profile.addAttribute("FALL_RESISTANCE", 5.225, 0);
    profile.addAttribute("SPRINT_SPEED", 0.21, 1);
    profile.addAttribute("BASE_SPEED", -0.21, 1);
}

function droughtSixProfile(profile) {
    profile.addAttribute("PUNCH_DAMAGE", 7.3, 0);
    profile.addAttribute("WEAPON_DAMAGE", 1.1, 0);
    profile.addAttribute("JUMP_HEIGHT", 0.8, 0);
    profile.addAttribute("FALL_RESISTANCE", 4.3, 0);
    profile.addAttribute("SPRINT_SPEED", 0.18, 1);
    profile.addAttribute("BASE_SPEED", -0.28, 1);
}

function droughtFiveProfile(profile) {
    profile.addAttribute("PUNCH_DAMAGE", 6.5, 0);
    profile.addAttribute("WEAPON_DAMAGE", 0.5, 0);
    profile.addAttribute("JUMP_HEIGHT", 0.625, 0);
    profile.addAttribute("FALL_RESISTANCE", 3.375, 0);
    profile.addAttribute("SPRINT_SPEED", 0.15, 1);
    profile.addAttribute("BASE_SPEED", -0.35, 1);
}

function droughtFourProfile(profile) {
    profile.addAttribute("PUNCH_DAMAGE", 5.7, 0);
    profile.addAttribute("WEAPON_DAMAGE", -0.1, 0);
    profile.addAttribute("JUMP_HEIGHT", 0.45, 0);
    profile.addAttribute("FALL_RESISTANCE", 2.45, 0);
    profile.addAttribute("SPRINT_SPEED", 0.12, 1);
    profile.addAttribute("BASE_SPEED", -0.42, 1);
}

function droughtThreeProfile(profile) {
    profile.addAttribute("PUNCH_DAMAGE", 4.9, 0);
    profile.addAttribute("WEAPON_DAMAGE", -0.7, 0);
    profile.addAttribute("JUMP_HEIGHT", 0.275, 0);
    profile.addAttribute("FALL_RESISTANCE", 1.525, 0);
    profile.addAttribute("SPRINT_SPEED", 0.09, 1);
    profile.addAttribute("BASE_SPEED", -0.49, 1);
}

function droughtTwoProfile(profile) {
    profile.addAttribute("PUNCH_DAMAGE", 4.1, 0);
    profile.addAttribute("WEAPON_DAMAGE", -1.3, 0);
    profile.addAttribute("JUMP_HEIGHT", 0.1, 0);
    profile.addAttribute("FALL_RESISTANCE", 0.6, 0);
    profile.addAttribute("SPRINT_SPEED", 0.06, 1);
    profile.addAttribute("BASE_SPEED", -0.56, 1);
}

function droughtOneProfile(profile) {
    profile.addAttribute("PUNCH_DAMAGE", 3.3, 0);
    profile.addAttribute("WEAPON_DAMAGE", -1.9, 0);
    profile.addAttribute("JUMP_HEIGHT", -0.075, 0);
    profile.addAttribute("FALL_RESISTANCE", -0.325, 0);
    profile.addAttribute("SPRINT_SPEED", 0.03, 1);
    profile.addAttribute("BASE_SPEED", -0.63, 1);
}

function droughtZeroProfile(profile) {
    profile.addAttribute("PUNCH_DAMAGE", 2.5, 0);
    profile.addAttribute("WEAPON_DAMAGE", -2.5, 0);
    profile.addAttribute("JUMP_HEIGHT", -0.25, 0);
    profile.addAttribute("FALL_RESISTANCE", -1.25, 0);
    profile.addAttribute("SPRINT_SPEED", 0.0, 1);
    profile.addAttribute("BASE_SPEED", -0.7, 1);
}